C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_SETQC     SET A BIT IN THE QUALITY CONTROL WORD
C   PRGMMR: SMITH, TRACY     ORG: ERL/FSL  DATE: 90-06-15
C
C ABSTRACT: SET A BIT IN QCIN.
C
C PROGRAM HISTORY LOG:
C      91-10-31   P. MILLER  CONVERTED TO BASELINE FORTRAN.
C      98-06-10   M. BARTH   ALLOWED 32 BITS TO BE USED (WAS 16).
C      99-09-20   M. BARTH   COPIED FROM MSAS & MODIFIED FOR MADIS
C      01-08-11   M. BARTH   CHANGED INV_INP_P TO INV_INTV_P
C      08-06-13   L. BENJAMIN CHANGED "MADISCON" INCLUDE TO 
C                             "INTQC1CON1".  
C
C USAGE:    CALL M_SETQC (QCIN, BITNUM, QCOUT, STATUS)
C
C   INPUT ARGUMENT LIST:
C     QCIN     - INTEGER                QC WORD TO SET
C     BITNUM   - INTEGER                BIT NUMBER TO SET
C
C   OUTPUT ARGUMENT LIST:
C     QCOUT    - INTEGER                RESULTING QC WORD
C     STATUS   - INTEGER                OUTPUT STATUS
C
C REMARKS:  N/A
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$
C**********************************************************************
C**********************************************************************

       SUBROUTINE M_SETQC (QCIN, BITNUM, QCOUT, STATUS)

C**********************************************************************
C**********************************************************************

      INCLUDE 'IMPLICIT'
      INCLUDE 'INTQC1CON1'
C
      INTEGER QCIN, QCOUT, BITNUM, STATUS, MASK
C
      IF (BITNUM.GE.1 .AND. BITNUM.LE.32) THEN
        MASK = 2**(BITNUM - 1)
        QCOUT = IOR(QCIN,MASK)
        STATUS = SUCCESS_P
      ELSE
        STATUS = INV_INTV_P
       ENDIF
      RETURN
       END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
